=======
Credits
=======

Development Lead
----------------

* Eliot Berriot <contact@eliotberriot.com>

Contributors
------------

* Ryan Anguiano, via `prefs-n-perms package <https://github.com/revpoint/prefs-n-perms>`_
